<?php
namespace Teknisa\MYM\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class Mym00107FaleConoscoController extends \Teknisa\GER\Controllers\TeknisaCrud {
    protected $crudService;
    protected $smtpService;
    protected $connection;
    protected $fileServerFilesUrl;
    
	public function __construct($smtpService, $crudService, $connection, $fileServerFilesUrl){
	    $this->SMTPService = $smtpService;
	    $this->crudService = $crudService;
	    $this->connection  = $connection;
	    $this->fileServerFilesUrl = $fileServerFilesUrl;
	    $this->templatesDir = __DIR__ . DIRECTORY_SEPARATOR . '..' . DIRECTORY_SEPARATOR . 'Templates' . DIRECTORY_SEPARATOR;
	}
    public function checkEmailRemetente(DTO\Request $request, DTO\Response $response){   
        try{
              $row = (array) $request->getRow();
                $conditions = array(
                    array(
                        "columnName" => "CDFILIAL",
                        "operator" => "=",
                        "value" => $row['CDFILIAL']
                    ),
                    array(
                        "columnName" => "NRORG",
                        "operator" => "=",
                        "value" => $this->crudService->getEnvironment()->getNrOrg()
                    )
                );
            $rows = $this->crudService->getFilteredDataSet('check_email_filial', $conditions)->getRows();
            $email = count($rows) > 0 ? $rows[0]['DSEMAILFILI'] : null;
            $response->addDataSet(new DataSet("emailOperador", array($email)));
        }  catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    //send email
    public function getFileContentUtf8($fileName) {
        $content = file_get_contents($fileName);
        return mb_convert_encoding($content, 'UTF-8', mb_detect_encoding($content, 'UTF-8, ISO-8859-1', true));
    }
    
    public function buildEmailLogoTemplate($message, $urlLogo, $idAplicativo) {
        $content = $this->getFileContentUtf8($this->templatesDir . "mail_logo.html");
        
        $title = "Tecfood ".$idAplicativo;

        $search = array(
            "%title%",
            "%message%",
            "%logoURL%",
            "%idAplicativo%"
        );
        $replace = array(
            $title,
            $message,
            $urlLogo['URLLOGO'],
            $idAplicativo
        );
        return str_replace($search, $replace, $content);
    }
    
    private function getFileUri($row) {
        $query = "
            SELECT URLLOGO FROM APPCONFIG
            WHERE
                IDAPLICATIVO = :IDAPLICATIVO
                AND NOT EXISTS (
                    SELECT
                        URLLOGO
                    FROM
                        QRCODELOCALPESQ
                    WHERE
                        CDFILIAL = :CDFILIAL
                        AND NVL(NRLOCALPESQ, 0) = NVL(:NRLOCALPESQ, 0)
                )
            UNION ALL
            SELECT
                MAX(URLLOGO) AS URLLOGO
            FROM
                QRCODELOCALPESQ
            WHERE
                CDFILIAL = :CDFILIAL
                AND NVL(NRLOCALPESQ, 0) = NVL(:NRLOCALPESQ, 0)
        ";
        
        $params = [
            "IDAPLICATIVO" => $row['IDAPLICATIVO'],
            "NRLOCALPESQ" => $row['NRLOCALPESQ'],
            "CDFILIAL" => $row['CDFILIAL']
        ];
        
        try{
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $rowResult = $std->fetch();
            return $rowResult;
        } catch(Exception $e) {
            throw $e;
        }
    }
    
    public function sendEmail(DTO\Request $request, DTO\Response $response){
        try{
            $row = (array) $request->getRow();
            $message = $row['MESSAGE'];
            $address = $row['EMAILCLIENTE'];
            $idAplicativo = $row['IDAPLICATIVO'];
            $logo = $this->getFileUri($row);
            $logo['URLLOGO'] = $this->fileServerFilesUrl.$logo['URLLOGO'];
            
            $mailBody = $this->buildEmailLogoTemplate($message, $logo, $idAplicativo);
            $this->SMTPService->setSubject('Resposta Fale Conosco MyMenu');
            $this->SMTPService->setFromName('SAC MyMenu');
            $this->SMTPService->sendMail($mailBody, $address);
        }catch(\Exception $e){
            $message = $e->getMessage();
            $errorMessage = "";
            
            if(stripos($message, "SMTP connect") !== false) { 
                $errorMessage = "SMTP_CONNECT_FAILED"; 
            } else {
                $errorMessage = "EMAIL_SENT_ERROR"; 
            }
            
            $response->setError(new Error($errorMessage,500));
            $response->addDataSet(new DataSet("sendEMailError", array('ERROR' => $e->getMessage())));
        }
    }
}
